@@ -13,12 +13,13 @@ typedef Eo Efl_Io_Copier;
 
 
 #endif
+#ifdef EFL_BETA_API_SUPPORT
 /**
  * @brief Copy from an @ref Efl_Io_Reader source to @ref Efl_Io_Writer
  * destination.
  *
  * During usage it will keep reference to @ref efl_io_copier_source_get and
- * @ref efl_io_copier_destination_get objects, automatically relasing them on
+ * @ref efl_io_copier_destination_get objects, automatically releasing them on
  * destruction.
  *
  * By default the read-write process is done based on fixed-size chunks
@@ -40,7 +41,7 @@ typedef Eo Efl_Io_Copier;
  * data when it's read from @ref efl_io_copier_source_get).
  *
  * - The "line" event is only emitted when
- * @ref efl_io_copier_line_delimiter_get is set and not empty. It's simiar to
+ * @ref efl_io_copier_line_delimiter_get is set and not empty. It's similar to
  * "data".
  *
  * - The "done" event is emitted if @ref efl_io_copier_source_get is
@@ -74,8 +75,6 @@ typedef Eo Efl_Io_Copier;
  * @ref efl_io_closer_close_on_invalidate_get are respected and applied to both
  * source and destination. Both default to @c true.
  *
- * @since 1.19
- *
  * @ingroup Efl_Io_Copier
  */
 #define EFL_IO_COPIER_CLASS efl_io_copier_class_get()
@@ -103,7 +102,7 @@ EWAPI const Efl_Class *efl_io_copier_class_get(void);
  * If there is a @ref efl_io_copier_line_delimiter_get set, then copier will
  * use that in order to attempt to write a full line at a time, including the
  * delimiter. Exceptions may be if the @ref efl_io_copier_source_get object
- * emitted "eos" and there is no trailing delimiter (ie: missing trailing
+ * emitted "eos" and there is no trailing delimiter (i.e: missing trailing
  * newline in files) or if the @ref efl_io_copier_buffer_limit_get is reached.
  *
  * Once @ref efl_io_reader_eos_get is @c true or "eos" event happen, then the
@@ -133,8 +132,6 @@ EWAPI const Efl_Class *efl_io_copier_class_get(void);
  * @param[in] obj The object.
  * @param[in] source @ref Efl_Io_Reader source
  *
- * @since 1.19
- *
  * @ingroup Efl_Io_Copier
  */
 EOAPI void efl_io_copier_source_set(Eo *obj, Efl_Io_Reader *source);
@@ -160,7 +157,7 @@ EOAPI void efl_io_copier_source_set(Eo *obj, Efl_Io_Reader *source);
  * If there is a @ref efl_io_copier_line_delimiter_get set, then copier will
  * use that in order to attempt to write a full line at a time, including the
  * delimiter. Exceptions may be if the @ref efl_io_copier_source_get object
- * emitted "eos" and there is no trailing delimiter (ie: missing trailing
+ * emitted "eos" and there is no trailing delimiter (i.e: missing trailing
  * newline in files) or if the @ref efl_io_copier_buffer_limit_get is reached.
  *
  * Once @ref efl_io_reader_eos_get is @c true or "eos" event happen, then the
@@ -189,8 +186,6 @@ EOAPI void efl_io_copier_source_set(Eo *obj, Efl_Io_Reader *source);
  *
  * @return @ref Efl_Io_Reader source
  *
- * @since 1.19
- *
  * @ingroup Efl_Io_Copier
  */
 EOAPI Efl_Io_Reader *efl_io_copier_source_get(const Eo *obj);
@@ -215,7 +210,7 @@ EOAPI Efl_Io_Reader *efl_io_copier_source_get(const Eo *obj);
  * If @ref efl_io_copier_source_get is flagged "eos" and all data is written to
  * the destination then the "done" event is emitted.
  *
- * If the destination is not set (ie: NULL) then data is kept in a internal
+ * If the destination is not set (ie: @c NULL) then data is kept in a internal
  * @ref Eina_Binbuf, which can be stolen with @ref efl_io_copier_binbuf_steal
  * once "data" or "line" events are emitted. It exists as a useful shortcut to
  * easily drain readers and store all data in memory with no need to use an
@@ -241,8 +236,6 @@ EOAPI Efl_Io_Reader *efl_io_copier_source_get(const Eo *obj);
  * @param[in] obj The object.
  * @param[in] destination @ref Efl_Io_Writer destination
  *
- * @since 1.19
- *
  * @ingroup Efl_Io_Copier
  */
 EOAPI void efl_io_copier_destination_set(Eo *obj, Efl_Io_Writer *destination);
@@ -267,7 +260,7 @@ EOAPI void efl_io_copier_destination_set(Eo *obj, Efl_Io_Writer *destination);
  * If @ref efl_io_copier_source_get is flagged "eos" and all data is written to
  * the destination then the "done" event is emitted.
  *
- * If the destination is not set (ie: NULL) then data is kept in a internal
+ * If the destination is not set (ie: @c NULL) then data is kept in a internal
  * @ref Eina_Binbuf, which can be stolen with @ref efl_io_copier_binbuf_steal
  * once "data" or "line" events are emitted. It exists as a useful shortcut to
  * easily drain readers and store all data in memory with no need to use an
@@ -292,8 +285,6 @@ EOAPI void efl_io_copier_destination_set(Eo *obj, Efl_Io_Writer *destination);
  *
  * @return @ref Efl_Io_Writer destination
  *
- * @since 1.19
- *
  * @ingroup Efl_Io_Copier
  */
 EOAPI Efl_Io_Writer *efl_io_copier_destination_get(const Eo *obj);
@@ -311,8 +302,6 @@ EOAPI Efl_Io_Writer *efl_io_copier_destination_get(const Eo *obj);
  * @param[in] obj The object.
  * @param[in] slice The contents may contain \0 and will be copied
  *
- * @since 1.19
- *
  * @ingroup Efl_Io_Copier
  */
 EOAPI void efl_io_copier_line_delimiter_set(Eo *obj, const Eina_Slice slice);
@@ -329,8 +318,6 @@ EOAPI void efl_io_copier_line_delimiter_set(Eo *obj, const Eina_Slice slice);
  *
  * @return The contents may contain \0 and will be copied
  *
- * @since 1.19
- *
  * @ingroup Efl_Io_Copier
  */
 EOAPI Eina_Slice efl_io_copier_line_delimiter_get(const Eo *obj);
@@ -364,8 +351,6 @@ EOAPI Eina_Slice efl_io_copier_line_delimiter_get(const Eo *obj);
  * @param[in] size Defines a maximum buffer limit, or 0 to allow unlimited
  * amount of bytes
  *
- * @since 1.19
- *
  * @ingroup Efl_Io_Copier
  */
 EOAPI void efl_io_copier_buffer_limit_set(Eo *obj, size_t size);
@@ -398,8 +383,6 @@ EOAPI void efl_io_copier_buffer_limit_set(Eo *obj, size_t size);
  * @return Defines a maximum buffer limit, or 0 to allow unlimited amount of
  * bytes
  *
- * @since 1.19
- *
  * @ingroup Efl_Io_Copier
  */
 EOAPI size_t efl_io_copier_buffer_limit_get(const Eo *obj);
@@ -424,8 +407,6 @@ EOAPI size_t efl_io_copier_buffer_limit_get(const Eo *obj);
  * @param[in] obj The object.
  * @param[in] size This is the chunk size to use for read operations
  *
- * @since 1.19
- *
  * @ingroup Efl_Io_Copier
  */
 EOAPI void efl_io_copier_read_chunk_size_set(Eo *obj, size_t size);
@@ -449,8 +430,6 @@ EOAPI void efl_io_copier_read_chunk_size_set(Eo *obj, size_t size);
  *
  * @return This is the chunk size to use for read operations
  *
- * @since 1.19
- *
  * @ingroup Efl_Io_Copier
  */
 EOAPI size_t efl_io_copier_read_chunk_size_get(const Eo *obj);
@@ -465,10 +444,8 @@ EOAPI size_t efl_io_copier_read_chunk_size_get(const Eo *obj);
  * @param[in] obj The object.
  * @param[out] read Amount of bytes read from source
  * @param[out] written Amount of bytes written to destination
- * @param[out] total If @ref efl_io_copier_source_get is an Efl.Io.Sizer, its
- * total size. Otherwise 0 to report unknown size
- *
- * @since 1.19
+ * @param[out] total If @ref efl_io_copier_source_get is an @ref Efl_Io_Sizer,
+ * its total size. Otherwise 0 to report unknown size
  *
  * @ingroup Efl_Io_Copier
  */
@@ -488,8 +465,6 @@ EOAPI void efl_io_copier_progress_get(const Eo *obj, uint64_t *read, uint64_t *w
  * @param[in] seconds Number inactive seconds to timeout this copier. If zero
  * or less, it will be disabled.
  *
- * @since 1.19
- *
  * @ingroup Efl_Io_Copier
  */
 EOAPI void efl_io_copier_timeout_inactivity_set(Eo *obj, double seconds);
@@ -509,8 +484,6 @@ EOAPI void efl_io_copier_timeout_inactivity_set(Eo *obj, double seconds);
  * @return Number inactive seconds to timeout this copier. If zero or less, it
  * will be disabled.
  *
- * @since 1.19
- *
  * @ingroup Efl_Io_Copier
  */
 EOAPI double efl_io_copier_timeout_inactivity_get(const Eo *obj);
@@ -528,8 +501,6 @@ EOAPI double efl_io_copier_timeout_inactivity_get(const Eo *obj);
  * @param[in] done If @c true, source is "eos" and all data was written to
  * "destination". If @c false, it's still pending some more copies
  *
- * @since 1.19
- *
  * @ingroup Efl_Io_Copier
  */
 EOAPI void efl_io_copier_done_set(Eo *obj, Eina_Bool done);
@@ -548,8 +519,6 @@ EOAPI void efl_io_copier_done_set(Eo *obj, Eina_Bool done);
  * @return If @c true, source is "eos" and all data was written to
  * "destination". If @c false, it's still pending some more copies
  *
- * @since 1.19
- *
  * @ingroup Efl_Io_Copier
  */
 EOAPI Eina_Bool efl_io_copier_done_get(const Eo *obj);
@@ -568,11 +537,9 @@ EOAPI Eina_Bool efl_io_copier_done_get(const Eo *obj);
  *
  * @return Binbuf
  *
- * @since 1.19
- *
  * @ingroup Efl_Io_Copier
  */
-EOAPI Eina_Binbuf *efl_io_copier_binbuf_steal(Eo *obj) EINA_WARN_UNUSED_RESULT;
+EOAPI Eina_Binbuf *efl_io_copier_binbuf_steal(Eo *obj) EFL_TRANSFER_OWNERSHIP EINA_WARN_UNUSED_RESULT;
 
 /**
  * @brief Returns the size of the pending buffer.
@@ -589,8 +556,6 @@ EOAPI Eina_Binbuf *efl_io_copier_binbuf_steal(Eo *obj) EINA_WARN_UNUSED_RESULT;
  *
  * @return The pending buffer size, in bytes.
  *
- * @since 1.19
- *
  * @ingroup Efl_Io_Copier
  */
 EOAPI size_t efl_io_copier_pending_size_get(const Eo *obj);
@@ -620,8 +585,6 @@ EOAPI size_t efl_io_copier_pending_size_get(const Eo *obj);
  *
  * @return @c true on success, @c false otherwise
  *
- * @since 1.19
- *
  * @ingroup Efl_Io_Copier
  */
 EOAPI Eina_Bool efl_io_copier_flush(Eo *obj, Eina_Bool may_block, Eina_Bool ignore_line_delimiter);
@@ -629,8 +592,6 @@ EOAPI Eina_Bool efl_io_copier_flush(Eo *obj, Eina_Bool may_block, Eina_Bool igno
 EWAPI extern const Efl_Event_Description _EFL_IO_COPIER_EVENT_DONE;
 
 /** All available data was copied from source to destination
- *
- * @since 1.19
  *
  * @ingroup Efl_Io_Copier
  */
@@ -641,8 +602,6 @@ EWAPI extern const Efl_Event_Description _EFL_IO_COPIER_EVENT_ERROR;
 /** An error happened and the copy stopped
  * @return Eina_Error
  *
- * @since 1.19
- *
  * @ingroup Efl_Io_Copier
  */
 #define EFL_IO_COPIER_EVENT_ERROR (&(_EFL_IO_COPIER_EVENT_ERROR))
@@ -650,8 +609,6 @@ EWAPI extern const Efl_Event_Description _EFL_IO_COPIER_EVENT_ERROR;
 EWAPI extern const Efl_Event_Description _EFL_IO_COPIER_EVENT_PROGRESS;
 
 /** Total size changed or Data was read/written
- *
- * @since 1.19
  *
  * @ingroup Efl_Io_Copier
  */
@@ -664,8 +621,6 @@ EWAPI extern const Efl_Event_Description _EFL_IO_COPIER_EVENT_DATA;
  * modified.
  * @return const Eina_Slice *
  *
- * @since 1.19
- *
  * @ingroup Efl_Io_Copier
  */
 #define EFL_IO_COPIER_EVENT_DATA (&(_EFL_IO_COPIER_EVENT_DATA))
@@ -677,10 +632,9 @@ EWAPI extern const Efl_Event_Description _EFL_IO_COPIER_EVENT_LINE;
  * should not be modified.
  * @return const Eina_Slice *
  *
- * @since 1.19
- *
  * @ingroup Efl_Io_Copier
  */
 #define EFL_IO_COPIER_EVENT_LINE (&(_EFL_IO_COPIER_EVENT_LINE))
+#endif /* EFL_BETA_API_SUPPORT */
 
 #endif
