@@ -13,8 +13,9 @@ typedef Eo Efl_Text_Markup;
 
 
 #endif
-#ifdef EFL_BETA_API_SUPPORT
 /** Markup data that populates the text object's style and format
+ *
+ * @since 1.24
  *
  * @ingroup Efl_Text_Markup
  */
@@ -28,6 +29,8 @@ EWAPI const Efl_Class *efl_text_markup_interface_get(void);
  * @param[in] obj The object.
  * @param[in] markup The markup-text representation set to this text.
  *
+ * @since 1.24
+ *
  * @ingroup Efl_Text_Markup
  */
 EOAPI void efl_text_markup_set(Eo *obj, const char *markup);
@@ -39,9 +42,10 @@ EOAPI void efl_text_markup_set(Eo *obj, const char *markup);
  *
  * @return The markup-text representation set to this text.
  *
+ * @since 1.24
+ *
  * @ingroup Efl_Text_Markup
  */
 EOAPI const char *efl_text_markup_get(const Eo *obj);
-#endif /* EFL_BETA_API_SUPPORT */
 
 #endif
