@@ -28,7 +28,7 @@ extern "C" {
  *
  * @date 2012 (created)
  *
- * @section toc Table of Contents
+ * @section eio_toc Table of Contents
  *
  * @li @ref eio_main_intro
  * @li @ref eio_main_compiling
@@ -133,12 +133,6 @@ typedef enum _Eio_File_Op Eio_File_Op;
  * @{
  */
 
-/**
- * @typedef Eio_File
- * Generic asynchronous I/O reference.
- */
-typedef struct _Eio_File Eio_File;
-
 /**
  * @typedef Eio_Progress
  * Progress information on a specific operation.
@@ -148,7 +142,6 @@ typedef struct _Eio_Progress Eio_Progress;
 typedef Eina_Bool (*Eio_Filter_Cb)(void *data, Eio_File *handler, const char *file);
 typedef void      (*Eio_Main_Cb)(void *data, Eio_File *handler, const char *file);
 
-typedef Eina_Bool (*Eio_Filter_Direct_Cb)(void *data, Eio_File *handler, const Eina_File_Direct_Info *info);
 typedef Eina_Bool (*Eio_Filter_Dir_Cb)(void *data, Eio_File *handler, Eina_File_Direct_Info *info);
 typedef void      (*Eio_Main_Direct_Cb)(void *data, Eio_File *handler, const Eina_File_Direct_Info *info);
 
@@ -401,6 +394,9 @@ EAPI Eio_File *eio_file_chmod(const char *path,
  *
  * This function will change the owner of a path, setting it to the user and
  * group passed as argument. It's equivalent to the chown shell command.
+ *
+ * @note Some platforms (including Windows) do not support chown(). In that
+ * case, this function returns @c NULL.
  */
 EAPI Eio_File *eio_file_chown(const char *path,
                               const char *user,
@@ -601,7 +597,7 @@ EAPI Eio_File *eio_file_xattr(const char *path,
                   const void *data);
 
 /**
- * @brief Define an extented attribute on a file/directory.
+ * @brief Define an extended attribute on a file/directory.
  * @param path The path to set the attribute on.
  * @param attribute The name of the attribute to define.
  * @param xattr_int The value to link the attribute with.
@@ -623,7 +619,7 @@ EAPI Eio_File *eio_file_xattr_int_set(const char *path,
                       const void *data);
 
 /**
- * @brief Define an extented attribute on a file/directory.
+ * @brief Define an extended attribute on a file/directory.
  * @param path The path to set the attribute on.
  * @param attribute The name of the attribute to define.
  * @param xattr_double The value to link the attribute with.
@@ -644,7 +640,7 @@ EAPI Eio_File *eio_file_xattr_double_set(const char *path,
                      Eio_Error_Cb error_cb,
                      const void *data);
 /**
- * @brief Define a string extented attribute on a file/directory.
+ * @brief Define a string extended attribute on a file/directory.
  * @param path The path to set the attribute on.
  * @param attribute The name of the attribute to define.
  * @param xattr_string The string to link the attribute with.
@@ -665,7 +661,7 @@ EAPI Eio_File *eio_file_xattr_string_set(const char *path,
                      Eio_Error_Cb error_cb,
                      const void *data);
 /**
- * @brief Define an extented attribute on a file/directory.
+ * @brief Define an extended attribute on a file/directory.
  * @param path The path to set the attribute on.
  * @param attribute The name of the attribute to define.
  * @param xattr_data The data to link the attribute with.
@@ -1181,12 +1177,12 @@ EAPI Eio_File *eio_eet_write_cipher(Eet_File *ef,
 EAPI extern int EIO_MONITOR_FILE_CREATED; /**< A new file was created in a watched directory */
 EAPI extern int EIO_MONITOR_FILE_DELETED; /**< A watched file was deleted, or a file in a watched directory was deleted */
 EAPI extern int EIO_MONITOR_FILE_MODIFIED; /**< A file was modified in a watched directory */
-EAPI extern int EIO_MONITOR_FILE_CLOSED; /**< A file was closed in a watched directory. This event is never sent on Windows and OSX */
+EAPI extern int EIO_MONITOR_FILE_CLOSED; /**< A file was closed in a watched directory. This event is never sent on Windows and OSX, or for non-fallback monitors */
 EAPI extern int EIO_MONITOR_DIRECTORY_CREATED; /**< A new directory was created in a watched directory */
 EAPI extern int EIO_MONITOR_DIRECTORY_DELETED; /**< A directory has been deleted: this can be either a watched directory or one of its subdirectories */
 EAPI extern int EIO_MONITOR_DIRECTORY_MODIFIED; /**< A directory has been modified in a watched directory */
-EAPI extern int EIO_MONITOR_DIRECTORY_CLOSED; /**< A directory has been closed in a watched directory. This event is never sent on Windows and OSX */
-EAPI extern int EIO_MONITOR_SELF_RENAME; /**< The monitored path has been renamed, an error could happen just after if the renamed path doesn't exist. This event is never sent on OSX */
+EAPI extern int EIO_MONITOR_DIRECTORY_CLOSED; /**< A directory has been closed in a watched directory. This event is never sent on Windows and OSX, or for non-fallback monitors */
+EAPI extern int EIO_MONITOR_SELF_RENAME; /**< The monitored path has been renamed, an error could happen just after if the renamed path doesn't exist. This event is never sent on OSX, or for non-fallback monitors */
 EAPI extern int EIO_MONITOR_SELF_DELETED; /**< The monitored path has been removed. This event is never sent on OSX */
 EAPI extern int EIO_MONITOR_ERROR; /**< During operation the monitor failed and will no longer work. eio_monitor_del must be called on it. */
 
@@ -1227,7 +1223,7 @@ EAPI Eio_Monitor *eio_monitor_add(const char *path);
  * @warning Do NOT pass non-stringshared strings to this function!
  *  If you don't know what this means, use eio_monitor_add().
  *
- * This fuction is just like eio_monitor_add(), however the string passed by
+ * This function is just like eio_monitor_add(), however the string passed by
  * argument must be created using eina_stringshare_add().
  */
 EAPI Eio_Monitor *eio_monitor_stringshared_add(const char *path);
@@ -1248,6 +1244,36 @@ EAPI void eio_monitor_del(Eio_Monitor *monitor);
  */
 EAPI const char *eio_monitor_path_get(Eio_Monitor *monitor);
 
+#ifdef EFL_BETA_API_SUPPORT
+/**
+ * @brief Check whether a monitor is using the fallback backend
+ * @param monitor The Eio_Monitor to check
+ * @return EINA_TRUE only if the monitor is valid and is using the fallback monitoring mechanism
+ *
+ * Fallback monitors are unable to provide the CLOSED or RENAME events. It's important
+ * to check whether a monitor is a fallback monitor before relying on these events.
+ *
+ * @since 1.21
+ */
+EAPI Eina_Bool eio_monitor_fallback_check(const Eio_Monitor *monitor);
+
+/**
+ * @brief Check if a monitor has the context about a file or not
+ * @param monitor The Eio_Monitor to check
+ * @param path The path to check
+ * @return EINA_TRUE if there is context, EINA_FALSE otherwise.
+ *
+ * There are Monitors that need context about a file before they can monitor the file correctly.
+ * As an example: If you publish a file in your API before the monitor has this file in his context,
+ * and the file gets deleted as a reaction to this, the monitor will not be able to emit the correct DELETE
+ * event even if the file is in the monitors path.
+ *
+ * In case the monitor does not yet have context, you can be sure that the monitor will bring up an FILE_ADD event about that file.
+ *
+ * @since 1.23
+ */
+EAPI Eina_Bool eio_monitor_has_context(const Eio_Monitor *monitor, const char *path);
+#endif
 /**
  * @}
  */
