@@ -14,10 +14,14 @@ typedef Eo Efl_Canvas_Gesture_Momentum;
 
 #endif
 #ifdef EFL_BETA_API_SUPPORT
-/** Momentum gesture class holding state information. See
+/**
+ * @brief Momentum gesture class holding state information. See
  * @ref Efl_Canvas_Gesture to see what this state is and
- * @[Efl.Gesture.Events.gesture,momentum] for a description of the Momentum
- * gesture.
+ * @[Efl.Canvas.Gesture_Events.gesture,momentum] for a description of the
+ * Momentum gesture.
+ *
+ * Application developers receive these objects inside a gesture event and do
+ * not typically need to create their own.
  *
  * @ingroup Efl_Canvas_Gesture_Momentum
  */
@@ -26,7 +30,7 @@ typedef Eo Efl_Canvas_Gesture_Momentum;
 EWAPI const Efl_Class *efl_canvas_gesture_momentum_class_get(void);
 
 /**
- * @brief Gets the momentum value, this is, the direction in which the action
+ * @brief The momentum value, this is, the direction in which the action
  * occurred.
  *
  * @param[in] obj The object.
@@ -35,7 +39,7 @@ EWAPI const Efl_Class *efl_canvas_gesture_momentum_class_get(void);
  *
  * @ingroup Efl_Canvas_Gesture_Momentum
  */
-EOAPI Eina_Vector2 efl_gesture_momentum_get(Eo *obj);
+EOAPI Eina_Vector2 efl_gesture_momentum_get(const Eo *obj);
 #endif /* EFL_BETA_API_SUPPORT */
 
 #endif
